==> frykit-0.7.1-py3-none-any.whl: frykit/shp/typing.py <==
from __future__ import annotations

from collections.abc import Sequence
from typing import Literal, TypedDict, TypeVar, Union

import shapely
from shapely.geometry.base import BaseGeometry

PointCoordinates = Sequence[float]
MultiPointCoordinates = Sequence[PointCoordinates]
LineStringCoordinates = Sequence[PointCoordinates]
MultiLineStringCoordinates = Sequence[LineStringCoordinates]
PolygonCoordinates = Sequence[LineStringCoordinates]
MultiPolygonCoordinates = Sequence[PolygonCoordinates]


# TODO: 用 NotRequired 标注 bbox 字段
class PointDict(TypedDict):
    type: Literal["Point"]
    coordinates: PointCoordinates


class MultiPointDict(TypedDict):
    type: Literal["MultiPoint"]
    coordinates: MultiPointCoordinates


class LineStringDict(TypedDict):
    type: Literal["LineString"]
    coordinates: LineStringCoordinates


class MultiLineStringDict(TypedDict):
    type: Literal["MultiLineString"]
    coordinates: MultiLineStringCoordinates


class PolygonDict(TypedDict):
    type: Literal["Polygon"]
    coordinates: PolygonCoordinates


class MultiPolygonDict(TypedDict):
    type: Literal["MultiPolygon"]
    coordinates: MultiPolygonCoordinates


# 此处只能用 Union？
GeometryDict = Union[
    PointDict,
    MultiPointDict,
    LineStringDict,
    MultiLineStringDict,
    PolygonDict,
    MultiPolygonDict,
    "GeometryCollectionDict",
]


class GeometryCollectionDict(TypedDict):
    type: Literal["GeometryCollection"]
    geometries: list[GeometryDict]


class FeatureDict(TypedDict):
    type: Literal["Feature"]
    geometry: GeometryDict
    properties: dict


class GeoJSONDict(TypedDict):
    type: Literal["FeatureCollection"]
    features: list[FeatureDict]


PointType = shapely.Point | shapely.MultiPoint
LineStringType = shapely.LineString | shapely.MultiLineString
PolygonType = shapely.Polygon | shapely.MultiPolygon
GeometryT = TypeVar("GeometryT", bound=BaseGeometry)

==> frykit-0.7.5.post1-py3-none-any.whl: frykit/shp/typing.py <==
from __future__ import annotations

from collections.abc import Sequence
from typing import Any, Literal, TypeAlias, TypedDict, TypeVar, Union

import shapely
from shapely.geometry.base import BaseGeometry

PointCoordinates: TypeAlias = Sequence[float]
MultiPointCoordinates: TypeAlias = Sequence[PointCoordinates]
LineStringCoordinates: TypeAlias = Sequence[PointCoordinates]
MultiLineStringCoordinates: TypeAlias = Sequence[LineStringCoordinates]
PolygonCoordinates: TypeAlias = Sequence[LineStringCoordinates]
MultiPolygonCoordinates: TypeAlias = Sequence[PolygonCoordinates]


# TODO: 用 NotRequired 标注 bbox 字段
class PointDict(TypedDict):
    type: Literal["Point"]
    coordinates: PointCoordinates


class MultiPointDict(TypedDict):
    type: Literal["MultiPoint"]
    coordinates: MultiPointCoordinates


class LineStringDict(TypedDict):
    type: Literal["LineString"]
    coordinates: LineStringCoordinates


class MultiLineStringDict(TypedDict):
    type: Literal["MultiLineString"]
    coordinates: MultiLineStringCoordinates


class PolygonDict(TypedDict):
    type: Literal["Polygon"]
    coordinates: PolygonCoordinates


class MultiPolygonDict(TypedDict):
    type: Literal["MultiPolygon"]
    coordinates: MultiPolygonCoordinates


# https://docs.python.org/3/library/stdtypes.html#union-type
GeometryDict: TypeAlias = Union[
    PointDict,
    MultiPointDict,
    LineStringDict,
    MultiLineStringDict,
    PolygonDict,
    MultiPolygonDict,
    "GeometryCollectionDict",
]


class GeometryCollectionDict(TypedDict):
    type: Literal["GeometryCollection"]
    geometries: list[GeometryDict]


class FeatureDict(TypedDict):
    type: Literal["Feature"]
    geometry: GeometryDict
    properties: dict[str, Any]


class GeoJSONDict(TypedDict):
    type: Literal["FeatureCollection"]
    features: list[FeatureDict]


PointType: TypeAlias = shapely.Point | shapely.MultiPoint
LineStringType: TypeAlias = shapely.LineString | shapely.MultiLineString
PolygonType: TypeAlias = shapely.Polygon | shapely.MultiPolygon
GeometryT = TypeVar("GeometryT", bound=BaseGeometry)
